'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.handleAtRule = handleAtRule;

var _cssAtRules = require('../../../constants/cssAtRules');

var _rePrefixedString = require('../../../constants/rePrefixedString');

var _countUsage = require('../../../calculators/countUsage');

var _handleVendorPrefix = require('../../handleVendorPrefix');

var _handleImport = require('../handleImport');

var _handleKeyframes = require('../handleKeyframes');

var _handleMediaQueryParams = require('../handleMediaQueryParams');

var _handleSupports = require('../handleSupports');

function handleAtRule(atRule, report, options) {
	report.atRules.total++;

	if (Array.isArray(atRule.nodes) && atRule.nodes.length === 0) {
		report.atRules.empty++;
	}

	(0, _countUsage.countUsage)(atRule.name, report.atRules.usage);

	/** Count vendor prefixes in at-rules names */
	if (_rePrefixedString.rePrefixedString.test(atRule.name)) {
		report.atRules.prefixed++;
		(0, _handleVendorPrefix.handleVendorPrefix)(atRule.name, report);
	}

	/** Count unknown at-rules */
	var unprefixedAtRuleName = atRule.name.replace(_rePrefixedString.rePrefixedString, '');
	if (_cssAtRules.cssAtRules.includes(unprefixedAtRuleName) === false) {
		report.atRules.unknown.total++;
		(0, _countUsage.countUsage)(atRule.name, report.atRules.unknown.usage);
	}

	if (atRule.name === 'import') {
		(0, _handleImport.handleImport)(atRule, report, options);
	}

	if (atRule.name === 'supports') {
		(0, _handleSupports.handleSupports)(atRule, report, options);
	}

	if (atRule.name === 'media') {
		(0, _handleMediaQueryParams.handleMediaQueryParams)(atRule.params, report, options);
	}

	if (unprefixedAtRuleName === 'keyframes') {
		(0, _handleKeyframes.handleKeyframes)(atRule, report);
	}

	/**
  * @font-face descriptors are not declarations
  */
	if (atRule.name !== 'font-face') {
		atRule.walkDecls(function (decl) {
			(0, _countUsage.countUsage)(atRule.name, report.declarations.inAtRules);
		});
	}
}