'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.handleKeyframes = handleKeyframes;

var _countUsage = require('../../../calculators/countUsage');

var _unique = require('../../../converters/unique');

var reNumberPercentage = /^(?:[0-9]+\.)?[0-9]+%$/;

function handleKeyframes(atRule, report) {
	var steps = [];

	atRule.walkRules(function (rule) {
		rule.selector.replace(/,\s+/g, ',').split(',').map(function (selector) {
			return selector.trim();
		}).forEach(function (part) {
			if (part === 'from') {
				steps.push(0);
			}

			if (reNumberPercentage.test(part)) {
				steps.push(Number(part.slice(0, -1)));
			}

			if (part === 'to') {
				steps.push(100);
			}
		});

		rule.walkDecls(function (decl) {
			if (report.keyframes.animatableProperties.includes(decl.prop) === false) {
				report.keyframes.animatableProperties.push(decl.prop);
			}
		});
	});

	var stepsUnique = (0, _unique.unique)(steps);

	var stepsChain = stepsUnique.sort(function (a, b) {
		return a - b;
	}).map(function (step) {
		return step + '%';
	}).join(' -> ');

	(0, _countUsage.countUsage)(stepsChain, report.keyframes.stepsChains);

	if (report.keyframes.longestStepsChainLength < stepsUnique.length) {
		report.keyframes.longestStepsChainLength = stepsUnique.length;
		report.keyframes.longestStepsChain = stepsChain;
		report.keyframes.longestStepsChainAnimation = atRule.params;
	}

	if (report.keyframes.shortestStepsChainLength > stepsUnique.length) {
		report.keyframes.shortestStepsChainLength = stepsUnique.length;
		report.keyframes.shortestStepsChain = stepsChain;
		report.keyframes.shortestStepsChainAnimation = atRule.params;
	}
}