'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.handleMediaQueryParams = handleMediaQueryParams;

var _cssBrowserHacks = require('../../../constants/cssBrowserHacks');

var _reCssMediaQueryFeature = require('../../../constants/reCssMediaQueryFeature');

var _reCssMediaQueryType = require('../../../constants/reCssMediaQueryType');

var _rePrefixedString = require('../../../constants/rePrefixedString');

var _countUsage = require('../../../calculators/countUsage');

var _removeExtraSpaces = require('../../../converters/removeExtraSpaces');

var _handleVendorPrefix = require('../../handleVendorPrefix');

var reOnlyKeyword = /\bonly\b/g;
var cssMediaBrowserHacks = _cssBrowserHacks.cssBrowserHacks.filter(function (hack) {
	return hack.type === 'media';
});

function handleMediaQueryParams(params, report, options) {
	report.mediaQueries.total++;

	var cleanedParams = (0, _removeExtraSpaces.removeExtraSpaces)(params);

	if (reOnlyKeyword.test(cleanedParams)) {
		report.mediaQueries.onlyKeyword += cleanedParams.match(reOnlyKeyword).length;
	}

	if (_reCssMediaQueryType.reCssMediaQueryType.test(cleanedParams)) {
		cleanedParams.match(_reCssMediaQueryType.reCssMediaQueryType).forEach(function (type) {
			report.mediaQueries.types.total++;
			(0, _countUsage.countUsage)(type, report.mediaQueries.types.usage);
		});
	}

	if (_reCssMediaQueryFeature.reCssMediaQueryFeature.test(cleanedParams)) {
		cleanedParams.match(_reCssMediaQueryFeature.reCssMediaQueryFeature).forEach(function (feature) {
			if (/^(min|max)--moz-/.test(feature)) {
				report.mediaQueries.features.prefixed++;
				(0, _handleVendorPrefix.handleVendorPrefix)('-moz-', report);
			} else if (_rePrefixedString.rePrefixedString.test(feature)) {
				report.mediaQueries.features.prefixed++;
				(0, _handleVendorPrefix.handleVendorPrefix)(feature, report);
			}

			report.mediaQueries.features.total++;
			(0, _countUsage.countUsage)(feature, report.mediaQueries.features.usage);
		});
	}

	(0, _countUsage.countUsage)(cleanedParams, report.mediaQueries.usage);

	if (options.browserHacks) {
		cssMediaBrowserHacks.forEach(function (hack) {
			if (hack.regex.test(cleanedParams)) {
				cleanedParams.match(hack.regex).forEach(function (match) {
					report.browserHacks.total++;
					(0, _countUsage.countUsage)(match, report.browserHacks.usage.media);
				});
			}
		});
	}
}