'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.handleUnits = handleUnits;

var _cssUnitsThatAllowZeroWithoutUnit = require('../../constants/cssUnitsThatAllowZeroWithoutUnit');

var _reCssValueWithUnit = require('../../constants/reCssValueWithUnit');

var _reUrlFunctionWithArg = require('../../constants/reUrlFunctionWithArg');

var _countUsage = require('../../calculators/countUsage');

var reAllowedLeadingSymbols = /(^|[(,\s])\s*/g;
var reCssValueWithUnitWithAllowedLeadingSymbols = new RegExp(reAllowedLeadingSymbols.source + _reCssValueWithUnit.reCssValueWithUnit.source, 'g');

var excludedUnitlessProps = ['animation-name', 'background-image', 'content', 'font-family'];

function handleUnits(decl, report, options) {
	if (excludedUnitlessProps.includes(decl.prop) && options.properties) {
		report.properties.unitless++;
		return;
	}

	/** Need to prevent units matching from data URIs in `url` function */
	var safedDeclValue = decl.prop === 'background' && _reUrlFunctionWithArg.reUrlFunctionWithArg.test(decl.value) ? decl.value.replace(_reUrlFunctionWithArg.reUrlFunctionWithArg, '') : decl.value;

	if (reCssValueWithUnitWithAllowedLeadingSymbols.test(safedDeclValue)) {
		safedDeclValue.match(reCssValueWithUnitWithAllowedLeadingSymbols)
		/* eslint-disable-next-line arrow-body-style */
		.map(function (match) {
			return match.replace(reAllowedLeadingSymbols, '').replace(/\(/g, '').replace(/,/g, '');
		}).forEach(function (match) {
			report.units.total++;

			/** Count negative margins */
			if (decl.prop.startsWith('margin') && match.startsWith('-') && options.properties) {
				report.properties.negativeMargins++;
			}

			/** Count excessive units, i.e. `0px` */
			if (parseFloat(match) === 0 && _cssUnitsThatAllowZeroWithoutUnit.cssUnitsThatAllowZeroWithoutUnit.some(function (unit) {
				return match.endsWith(unit);
			})) {
				report.units.excessive.total++;
				(0, _countUsage.countUsage)(match, report.units.excessive.usage);
			}

			var unit = match.replace(/[-.0-9]+/g, '');
			(0, _countUsage.countUsage)(unit, report.units.usage);
		});
	} else if (options.properties) {
		report.properties.unitless++;
	}
}